==> illumination_0.1.20091009-1.tar.gz: illumination-0.1.20091009/include/Lum/OS/Base/Behaviour.h <==
#ifndef LUM_OS_BASE_BEHAVIOUR_H
#define LUM_OS_BASE_BEHAVIOUR_H

/*
  This source is part of the Illumination library
  Copyright (C) 2009  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/OS/Behaviour.h>

namespace Lum {
  namespace OS {
    namespace Base {

      class Behaviour : public OS::Behaviour
      {
      };

      class DefaultBehaviour : public Behaviour
      {
      public:
        DefaultBehaviour();
        ~DefaultBehaviour();

        CustomMenuHandler* GetCustomMenuHandler(OS::Window* window) const;
        void ApplyMultiViewDlg(Dialog* dialog,
                               const Def::MultiView& multiView) const;
        Lum::Object* GetOneOfManyControl(Def::OneOfMany& def) const;
        Lum::Object* GetOneOfManyControl(Def::OneOfMany& def,
                                         bool horizFlex,
                                         bool vertFlex) const;
      };
    }
  }
}

#endif

==> illumination_0.1.20100208-1.tar.gz: illumination-0.1.20100208/include/Lum/OS/Base/Behaviour.h <==
#ifndef LUM_OS_BASE_BEHAVIOUR_H
#define LUM_OS_BASE_BEHAVIOUR_H

/*
  This source is part of the Illumination library
  Copyright (C) 2009  Tim Teulings

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
*/

#include <Lum/OS/Behaviour.h>

namespace Lum {
  namespace OS {
    namespace Base {

      class Behaviour : public OS::Behaviour
      {
      };

      class DefaultBehaviour : public Behaviour
      {
      public:
        DefaultBehaviour();
        ~DefaultBehaviour();

        bool FocusObjectOnWindowFocusIn() const;
        bool ScrollKnobActive() const;

        CustomMenuHandler* GetCustomMenuHandler(OS::Window* window) const;
        void ApplyMultiViewDlg(Dialog* dialog,
                               const Def::MultiView& multiView) const;

        Lum::Object* GetOneOfManyControl(Def::OneOfMany& def) const;
        Lum::Object* GetOneOfManyControl(Def::OneOfMany& def,
                                         bool horizFlex,
                                         bool vertFlex) const;

        Lum::Object* GetBooleanControl(Def::Boolean& def) const;
        Lum::Object* GetBooleanControl(Def::Boolean& def,
                                       bool horizFlex,
                                       bool vertFlex) const;
      };
    }
  }
}

#endif
